# Google Earth Overlay Server (GEOS)

This is a python-based server for creating Google Earth overlays
of tiled maps. Your can now also display maps in the web browser,
measure distances and print maps as high-quality PDF's.

Developers can also use *GEOS* as a library to convert coordinates
or to access the map printing functionality programmatically.


```eval_rst
.. toctree::
    :maxdepth: 2 

    self
    users.md
    developers.md
```

